==> hive-apache-3.0.0-4-sources.jar: org/apache/hadoop/hive/ql/parse/repl/load/log/state/IncrementalLoadEvent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hive.ql.parse.repl.load.log.state;

import org.apache.hadoop.hive.ql.parse.repl.ReplState;
import io.prestosql.hive.$internal.org.codehaus.jackson.annotate.JsonProperty;

public class IncrementalLoadEvent extends ReplState {
  @JsonProperty
  private String dbName;

  @JsonProperty
  private String eventId;

  @JsonProperty
  private String eventType;

  @JsonProperty
  private String eventsLoadProgress;

  @JsonProperty
  private Long loadTime;

  public IncrementalLoadEvent(String dbName,
                              String eventId,
                              String eventType,
                              long eventSeqNo,
                              long numEvents) {
    this.dbName = dbName;
    this.eventId = eventId;
    this.eventType = eventType;
    this.eventsLoadProgress = new String(new StringBuilder()
                                            .append(eventSeqNo).append("/").append(numEvents));
    this.loadTime = System.currentTimeMillis() / 1000;
  }
}

==> hive-apache-3.1.2-21-sources.jar: org/apache/hadoop/hive/ql/parse/repl/load/log/state/IncrementalLoadEvent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hive.ql.parse.repl.load.log.state;

import org.apache.hadoop.hive.ql.parse.repl.ReplState;
import io.trino.hive.$internal.org.codehaus.jackson.annotate.JsonProperty;

public class IncrementalLoadEvent extends ReplState {
  @JsonProperty
  private String dbName;

  @JsonProperty
  private String eventId;

  @JsonProperty
  private String eventType;

  @JsonProperty
  private String eventsLoadProgress;

  @JsonProperty
  private Long loadTime;

  public IncrementalLoadEvent(String dbName,
                              String eventId,
                              String eventType,
                              long eventSeqNo,
                              long numEvents) {
    this.dbName = dbName;
    this.eventId = eventId;
    this.eventType = eventType;
    this.eventsLoadProgress = new String(new StringBuilder()
                                            .append(eventSeqNo).append("/").append(numEvents));
    this.loadTime = System.currentTimeMillis() / 1000;
  }
}
